Documentation
¶
Index ¶
- func BulkDelete(ctx context.Context, client *redis.Client, keys []string) tea.Cmd
- func CopyValueToClipboard(ctx context.Context, value string) tea.Cmd
- func DeleteKey(ctx context.Context, client *redis.Client, key string) tea.Cmd
- func DisplayEmptyValue() tea.Msg
- func GetKeys(ctx context.Context, redis *redis.Client, pattern string) tea.Cmd
- func GetValue(ctx context.Context, redis *redis.Client, key string) tea.Cmd
- func NewErrorInfoCmd(id infoid.InfoID, err error, expiresIn time.Duration) tea.Cmd
- func NewErrorMsg(id infoid.InfoID, err error, expiresIn time.Duration) tea.Msg
- func NewInfoInfoCmd(id infoid.InfoID, text string, expiresIn time.Duration) tea.Cmd
- func NewInfoMsg(id infoid.InfoID, text string, expiresIn time.Duration) tea.Msg
- func NewWarningMsg(id infoid.InfoID, text string, expiresIn time.Duration) tea.Msg
- func SwitchTab(ctx context.Context, client *redis.Client, tab int) tea.Cmd
- func UpdateSelectedItemCmd(newKey string) tea.Msg
- func UpdateValue(ctx context.Context, client *redis.Client, key string, newValue string) tea.Cmd
- type CopySuccessMsg
- type HighlightedKeyUpdatedMsg
- type InfoExpiredMsg
- type InfoMsg
- type InfoType
- type InfoTypeError
- type InfoTypeInfo
- type InfoTypeNone
- type InfoTypeWarning
- type KeyDeletedMsg
- type KeysUpdatedMsg
- type MsgWithKind
- type NewRedisClientMsg
- type TickMsg
- type ValueUpdatedMsg
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DisplayEmptyValue ¶
func NewErrorInfoCmd ¶ added in v0.1.5
NewErrorInfoCmd is a helper function to create a error info command.
func NewInfoInfoCmd ¶ added in v0.1.5
NewWarningInfoCmd is a helper function to create a info command.
func NewInfoMsg ¶
NewInfoMsg creates a command that sends an InfoMsg with the given InfoType.
func NewWarningMsg ¶
func UpdateSelectedItemCmd ¶
Types ¶
type CopySuccessMsg ¶
type CopySuccessMsg struct{}
type HighlightedKeyUpdatedMsg ¶
type HighlightedKeyUpdatedMsg struct {
Key string
}
func (HighlightedKeyUpdatedMsg) String ¶ added in v0.1.5
func (h HighlightedKeyUpdatedMsg) String() string
type InfoExpiredMsg ¶
type InfoExpiredMsg struct {
Id infoid.InfoID // Unique identifier for the message that has expired
}
func (InfoExpiredMsg) String ¶ added in v0.1.5
func (i InfoExpiredMsg) String() string
type InfoTypeError ¶
type InfoTypeError struct {
InfoId infoid.InfoID // Unique identifier for the message
Err error // Error
ExpiresIn time.Duration // Duration after which the message expires
}
Error info type
func (InfoTypeError) Expires ¶
func (i InfoTypeError) Expires() time.Duration
func (InfoTypeError) Type ¶
func (i InfoTypeError) Type() string
type InfoTypeInfo ¶
type InfoTypeInfo struct {
InfoId infoid.InfoID // Unique identifier for the message
Text string // The informational message text
ExpiresIn time.Duration // Duration after which the message expires
}
Info info type
func (InfoTypeInfo) Expires ¶
func (i InfoTypeInfo) Expires() time.Duration
func (InfoTypeInfo) Type ¶
func (i InfoTypeInfo) Type() string
type InfoTypeNone ¶
type InfoTypeNone struct{}
None info type
func (InfoTypeNone) Type ¶
func (i InfoTypeNone) Type() string
type InfoTypeWarning ¶
type InfoTypeWarning struct {
InfoId infoid.InfoID // Unique identifier for the message
Text string // The warning message text
ExpiresIn time.Duration // Duration after which the message expires
}
Warning info type
func (InfoTypeWarning) Expires ¶
func (i InfoTypeWarning) Expires() time.Duration
func (InfoTypeWarning) Type ¶
func (i InfoTypeWarning) Type() string
type KeyDeletedMsg ¶
type KeyDeletedMsg struct {
Key string
// contains filtered or unexported fields
}
func (KeyDeletedMsg) String ¶ added in v0.1.5
func (k KeyDeletedMsg) String() string
type KeysUpdatedMsg ¶
type KeysUpdatedMsg struct {
Keys []string
}
func (KeysUpdatedMsg) String ¶ added in v0.1.5
func (KeysUpdatedMsg) String() string
type MsgWithKind ¶
type MsgWithKind interface {
String() string
}
type NewRedisClientMsg ¶
func (NewRedisClientMsg) String ¶ added in v0.1.5
func (n NewRedisClientMsg) String() string
type ValueUpdatedMsg ¶
type ValueUpdatedMsg struct {
NewValue string // The new value for the key
TTL int64 // Time to live for the key, if applicable
}
func (ValueUpdatedMsg) String ¶ added in v0.1.5
func (v ValueUpdatedMsg) String() string
Click to show internal directories.
Click to hide internal directories.